window.Gleam.initSearch([{"doc":"filepath","title":"filepath","content":"# filepath\n\nWork with file paths in Gleam!\n\n[![Package Version](https://img.shields.io/hexpm/v/filepath)](https://hex.pm/packages/filepath)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/filepath/)\n\n```sh\ngleam add filepath\n```\n```gleam\nimport filepath\n\npub fn main() {\n  let path = filepath.join(&quot;/home/lucy&quot;, &quot;pokemon-cards&quot;)\n  // -&gt; &quot;/home/lucy/pokemon-cards&quot;\n}\n```\n\nDocumentation can be found here: &lt;https://hexdocs.pm/filepath&gt;.\n","url":"index.html"},{"doc":"filepath","title":"base_name","content":"pub fn base_name(path: String) -&gt; String\n Get the base name of a path, that is the name of the file without the\n containing directory.\n\n ## Examples\n\n \n base_name(&quot;/usr/local/bin&quot;)\n // -&gt; &quot;bin&quot;\n \n\nSynonyms:\nfilepath.base_name\nfilepath base_name","url":"filepath.html#base_name"},{"doc":"filepath","title":"directory_name","content":"pub fn directory_name(path: String) -&gt; String\n Get the directory name of a path, that is the path without the file name.\n\n ## Examples\n\n \n directory_name(&quot;/usr/local/bin&quot;)\n // -&gt; &quot;/usr/local&quot;\n \n\nSynonyms:\nfilepath.directory_name\nfilepath directory_name","url":"filepath.html#directory_name"},{"doc":"filepath","title":"expand","content":"pub fn expand(path: String) -&gt; Result(String, Nil)\n Expand `..` and `.` segments in a path.\n\n If the path has a `..` segment that would go up past the root of the path\n then an error is returned. This may be useful to example to ensure that a\n path specified by a user does not go outside of a directory.\n\n If the path is absolute then the result will always be absolute.\n\n ## Examples\n\n \n expand(&quot;/usr/local/../bin&quot;)\n // -&gt; Ok(&quot;/usr/bin&quot;)\n \n\n \n expand(&quot;/tmp/../..&quot;)\n // -&gt; Error(Nil)\n \n\n \n expand(&quot;src/../..&quot;)\n // -&gt; Error(&quot;..&quot;)\n \n\nSynonyms:\nfilepath.expand\nfilepath expand","url":"filepath.html#expand"},{"doc":"filepath","title":"extension","content":"pub fn extension(path: String) -&gt; Result(String, Nil)\n Get the file extension of a path.\n\n ## Examples\n\n \n extension(&quot;src/main.gleam&quot;)\n // -&gt; Ok(&quot;gleam&quot;)\n \n\n \n extension(&quot;package.tar.gz&quot;)\n // -&gt; Ok(&quot;gz&quot;)\n \n\nSynonyms:\nfilepath.extension\nfilepath extension","url":"filepath.html#extension"},{"doc":"filepath","title":"is_absolute","content":"pub fn is_absolute(path: String) -&gt; Bool\n Check if a path is absolute.\n\n ## Examples\n\n \n is_absolute(&quot;/usr/local/bin&quot;)\n // -&gt; True\n \n\n \n is_absolute(&quot;usr/local/bin&quot;)\n // -&gt; False\n \n\nSynonyms:\nfilepath.is_absolute\nfilepath is_absolute","url":"filepath.html#is_absolute"},{"doc":"filepath","title":"join","content":"pub fn join(left: String, right: String) -&gt; String\n Join two paths together.\n\n This function does not expand `..` or `.` segments, use the `expand`\n function to do this.\n\n ## Examples\n\n \n join(&quot;/usr/local&quot;, &quot;bin&quot;)\n // -&gt; &quot;/usr/local/bin&quot;\n \n\nSynonyms:\nfilepath.join\nfilepath join","url":"filepath.html#join"},{"doc":"filepath","title":"split","content":"pub fn split(path: String) -&gt; List(String)\n Split a path into its segments.\n\n When running on Windows both `/` and `\\` are treated as path separators, and \n if the path starts with a drive letter then the drive letter then it is\n lowercased.\n\n ## Examples\n\n \n split(&quot;/usr/local/bin&quot;, &quot;bin&quot;)\n // -&gt; [&quot;/&quot;, &quot;usr&quot;, &quot;local&quot;, &quot;bin&quot;]\n \n\nSynonyms:\nfilepath.split\nfilepath split","url":"filepath.html#split"},{"doc":"filepath","title":"split_unix","content":"pub fn split_unix(path: String) -&gt; List(String)\n Split a path into its segments, using `/` as the path separator.\n\n Typically you would want to use `split` instead of this function, but if you\n want non-Windows path behaviour on a Windows system then you can use this\n function.\n\n ## Examples\n\n \n split(&quot;/usr/local/bin&quot;, &quot;bin&quot;)\n // -&gt; [&quot;/&quot;, &quot;usr&quot;, &quot;local&quot;, &quot;bin&quot;]\n \n\nSynonyms:\nfilepath.split_unix\nfilepath split_unix","url":"filepath.html#split_unix"},{"doc":"filepath","title":"split_windows","content":"pub fn split_windows(path: String) -&gt; List(String)\n Split a path into its segments, using `/` and `\\` as the path separators. If\n there is a drive letter at the start of the path then it is lowercased.\n\n Typically you would want to use `split` instead of this function, but if you\n want Windows path behaviour on a non-Windows system then you can use this\n function.\n\n ## Examples\n\n \n split(&quot;/usr/local/bin&quot;, &quot;bin&quot;)\n // -&gt; [&quot;/&quot;, &quot;usr&quot;, &quot;local&quot;, &quot;bin&quot;]\n \n\nSynonyms:\nfilepath.split_windows\nfilepath split_windows","url":"filepath.html#split_windows"},{"doc":"filepath","title":"strip_extension","content":"pub fn strip_extension(path: String) -&gt; String\n Remove the extension from a file, if it has any.\n \n ## Examples\n \n \n strip_extension(&quot;src/main.gleam&quot;)\n // -&gt; &quot;src/main&quot;\n \n \n \n strip_extension(&quot;package.tar.gz&quot;)\n // -&gt; &quot;package.tar&quot;\n \n \n \n strip_extension(&quot;src/gleam&quot;)\n // -&gt; &quot;src/gleam&quot;\n \n \nSynonyms:\nfilepath.strip_extension\nfilepath strip_extension","url":"filepath.html#strip_extension"},{"doc":"filepath","title":"filepath","content":" Work with file paths in Gleam!\n\n This library expects paths to be valid unicode. If you need to work with\n non-unicode paths you will need to convert them to unicode before using\n this library.","url":"filepath.html"}]);